@@ -19,10 +19,11 @@
 #include <QtCore/qstringlist.h>
 #include <QtCore/qlist.h>
 
-#include "qaudio.h"
-#include "qaudiodevice.h"
-#include "qgst_handle_types_p.h"
-#include <private/qaudiodevice_p.h>
+#include <QtMultimedia/qaudio.h>
+#include <QtMultimedia/qaudiodevice.h>
+#include <QtMultimedia/private/qaudiodevice_p.h>
+
+#include <QtQGstreamerMediaPluginImpl/private/qgst_handle_types_p.h>
 
 #include <gst/gst.h>
 
@@ -32,11 +33,22 @@ class QGStreamerAudioDeviceInfo : public QAudioDevicePrivate
 {
 public:
     QGStreamerAudioDeviceInfo(GstDevice *gstDevice, const QByteArray &device, QAudioDevice::Mode mode);
-    ~QGStreamerAudioDeviceInfo();
 
     QGstDeviceHandle gstDevice;
 };
 
+class QGStreamerCustomAudioDeviceInfo : public QAudioDevicePrivate
+{
+public:
+    QGStreamerCustomAudioDeviceInfo(const QByteArray &gstreamerPipeline, QAudioDevice::Mode mode);
+};
+
+bool isCustomAudioDevice(const QAudioDevicePrivate *device);
+bool isCustomAudioDevice(const QAudioDevice &device);
+
+QAudioDevice qMakeCustomGStreamerAudioInput(const QByteArray &gstreamerPipeline);
+QAudioDevice qMakeCustomGStreamerAudioOutput(const QByteArray &gstreamerPipeline);
+
 QT_END_NAMESPACE
 
 #endif
